# API Reference - Other Components

This section of the documentation provides a reference for the API of the  nodes.catchment, nodes.demand, nodes.distribution, and nodes.waste modules.

::: wsimod.nodes.catchment
::: wsimod.nodes.demand
::: wsimod.nodes.distribution
::: wsimod.nodes.waste
